@@ -13,7 +13,7 @@ use Test::BDD::Cucumber::Definitions qw(S);
 use Test::BDD::Cucumber::Definitions::Validator qw(:all);
 use Test::More;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 our @EXPORT_OK = qw(
     http_request_header_set
@@ -66,7 +66,7 @@ sub http_request_send {
 
     my $options = {
         headers => S->{http}->{request}->{headers},
-        content => S->{http}->{request}->{content},
+        content => _encode_utf8( S->{http}->{request}->{content} ),
     };
 
     S->{http}->{response} = $http->request( $method, $url, $options );
@@ -144,4 +144,14 @@ sub http_response_content_re {
     return;
 }
 
+sub _encode_utf8 {
+    my ($str) = @_;
+
+    if ( utf8::is_utf8 $str ) {
+        utf8::encode $str;
+    }
+
+    return $str;
+}
+
 1;
